pub struct ResourceManagementSignals {
pub context_managers: Vec<Evidence>,
pub enter_exit_methods: Vec<Evidence>,
pub defer_statements: Vec<Evidence>,
pub drop_impls: Vec<Evidence>,
pub try_finally_blocks: Vec<Evidence>,
pub close_calls: Vec<Evidence>,
}Expand description
Signals related to resource management patterns detected during AST traversal.
Fields
context_managers: Vec<Evidence>Python context managers (with statements)
enter_exit_methods: Vec<Evidence>Python enter/exit methods
defer_statements: Vec<Evidence>Go defer statements
drop_impls: Vec<Evidence>Rust Drop trait implementations
try_finally_blocks: Vec<Evidence>TypeScript/JS try/finally blocks
close_calls: Vec<Evidence>Explicit close calls
Implementations
Sourceimpl ResourceManagementSignals
impl ResourceManagementSignals
Sourcepub fn merge(&mut self, other: &ResourceManagementSignals)
pub fn merge(&mut self, other: &ResourceManagementSignals)
Merge signals from another ResourceManagementSignals instance into this one.
Sourcepub fn has_signals(&self) -> bool
pub fn has_signals(&self) -> bool
Returns true if any resource management signals have been collected.
Sourcepub fn calculate_confidence(&self) -> f64
pub fn calculate_confidence(&self) -> f64
Calculate confidence score (0.0-1.0) based on accumulated resource management signals.