Error types for TLDR operations
This module defines the error taxonomy for all TLDR operations. Error messages are designed to match Python output format (M17: Error Message Parity).
Enums
- Tldr
Error - All possible errors from TLDR operations.